#ifndef NT2_INCLUDE_FUNCTIONS_FAST_GAMMA_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_FAST_GAMMA_HPP_INCLUDED

#include <nt2/euler/include/functions/fast_gamma.hpp>

#endif
